==> ocstore25_4_23.zip: OcStore/Prgm/data/CS_mission.lua <==
----------------任务---------------
function ItemSystem_AskEveryoneAboutMahin()
    TUR()MSG("\n*向大家询问马宾去向*")W99()
end
function ItemSystem_AskEveryoneAboutMahin_Check()
    MSG("去向村子里大家询问一下")
    CAT("\n马宾的下落吧。")NOD()W99()
end
RGM("AskEveryoneAboutMahin","CS_mission_kanpa","向大家询问马宾去向","ItemSystem_AskEveryoneAboutMahin","ItemSystem_AskEveryoneAboutMahin_Check")


function ItemSystem_GoHomeSleep()
    TUR()MSG("\n*回家睡觉*")W99()
end
function ItemSystem_GoHomeSleep_Check()
    MSG("太阳已经下山了")
    CAT("\n回屋子休息吧。")NOD()W99()
end
RGM("GoHomeSleep","CS_mission_kanpa","回家睡觉","ItemSystem_GoHomeSleep","ItemSystem_GoHomeSleep_Check")

function ItemSystem_SearchForMahin()
    TUR()MSG("\n*出发寻找马宾*")W99()
end
function ItemSystem_SearchForMahin_Check()
    MSG("马宾已经失踪三天了")
    CAT("\n我得去村子外边找他。")NOD()W99()
end
RGM("SearchForMahin","CS_mission_kanpa","出发寻找马宾","ItemSystem_SearchForMahin","ItemSystem_SearchForMahin_Check")

function ItemSystem_Fishing()
    TUR()MSG("\n*去钓大鱼吧*")W99()
end
function ItemSystem_Fishing_Check()
    MSG("钓大鱼去喂给猫先生吧~")
    CAT("\n这样它就会帮我一起找马宾了。")NOD()W99()
end
RGM("Fishing","CS_mission_monsterx","去钓大鱼吧","ItemSystem_Fishing","ItemSystem_Fishing_Check")

function ItemSystem_BackVillageReport()
    TUR()MSG("\n*回村报告*")W99()
end
function ItemSystem_BackVillageReport_Check()
    MSG("今天时间已经晚了，")
    CAT("\n得回村子和杰克报告一下...")NOD()W99()
end
RGM("BackVillageReport","CS_mission_kanpa","回村报告","ItemSystem_BackVillageReport","ItemSystem_BackVillageReport_Check")

function ItemSystem_SaveToroko()
    TUR()MSG("\n*救回多隆子*")W99()
end
function ItemSystem_SaveToroko_Check()
    MSG("多隆子被怪物抓走了，")
    CAT("\n我们必须去救回她...")NOD()W99()
end
RGM("SaveToroko","CS_mission_jack","救回多隆子","ItemSystem_SaveToroko","ItemSystem_SaveToroko_Check")

function ItemSystem_AskMiseryForHelp()
    TUR()MSG("\n*向米莎莉求助*")W99()
end
function ItemSystem_AskMiseryForHelp_Check()
    MSG("向米莎莉求助试试")
    CAT("\n寻找救回多隆子的方法...")NOD()W99()
end
RGM("AskMiseryForHelp","CS_mission_jack","向米莎莉求助","ItemSystem_AskMiseryForHelp","ItemSystem_AskMiseryForHelp_Check")

function ItemSystem_AskBalrogForHelp()
    TUR()MSG("\n*向巴鲁罗格求助*")W99()
end
function ItemSystem_AskBalrogForHelp_Check()
    MSG("不小心惹米莎莉生气了")
    CAT("\n回酒店再向巴鲁罗格问一下吧...")NOD()W99()
end
RGM("AskBalrogForHelp","CS_mission_jack","向巴鲁罗格求助","ItemSystem_AskBalrogForHelp","ItemSystem_AskBalrogForHelp_Check")

function ItemSystem_SearchingForMethodsToCaptureFireflies()
    TUR()MSG("\n*寻找捕获萤火虫的方法*")W99()
end
function ItemSystem_SearchingForMethodsToCaptureFireflies_Check()
    MSG("听巴鲁罗格说")
    CAT("\n米莎莉小时候喜欢萤火虫。")NOD()CLR()
    CAT("不过目前我们没有捕获萤火虫的工具，")NOD()
    CAT("\n得在这个小镇上寻找方法。")NOD()W99()
end
RGM("SearchingForMethodsToCaptureFireflies","CS_mission_jack","寻找捕获萤火虫的方法",
"ItemSystem_SearchingForMethodsToCaptureFireflies","ItemSystem_SearchingForMethodsToCaptureFireflies_Check")

function ItemSystem_GetTranslator()
    TUR()MSG("\n*取得一台翻译机*")W99()
end
function ItemSystem_GetTranslator_Check()
    MSG("如果要和人类对话的话，")NOD()
    CAT("\n需要一台翻译机。")NOD()CLR()
    CAT("伊格尔说回收店里也许有翻译机卖，")NOD()
    CAT("\n我们得去回收店看看。")NOD()W99()
end
RGM("GetTranslator","CS_mission_jack","取得一台翻译机","ItemSystem_GetTranslator","ItemSystem_GetTranslator_Check")

function ItemSystem_AskGunsmithForHelp()
    TUR()MSG("\n*向制枪者求助*")W99()
end
function ItemSystem_AskGunsmithForHelp_Check()
    MSG("听茶羽说制枪者")
    CAT("\n能帮我们找到捕获办法，")NOD()
    CAT("\n去他的维修店里看一下吧。")NOD()
    W99()
end
RGM("AskGunsmithForHelp","CS_mission_jack","向制枪者求助","ItemSystem_AskGunsmithForHelp","ItemSystem_AskGunsmithForHelp_Check")

function ItemSystem_BringSomeDessert()
    TUR()MSG("\n*带甜点给制枪者*")W99()
end
function ItemSystem_BringSomeDessert_Check()
    MSG("制枪者需要吃一些甜点恢复脑力来制作，")NOD()
    CAT("\n去蛋糕店看一下吧。")NOD()
    W99()
end
RGM("BringSomeDessert","CS_mission_jack","带甜点给制枪者","ItemSystem_BringSomeDessert","ItemSystem_BringSomeDessert_Check")

function ItemSystem_LackOfHoney()
    TUR()MSG("\n*缺少蜂蜜的报告*")W99()
end
function ItemSystem_LackOfHoney_Check()
    MSG("把蛋糕店无法继续制作甜点的原因")
    CAT("\n和制枪者说一下吧。")NOD()
    W99()
end
RGM("LackOfHoney","CS_mission_jack","缺少蜂蜜的报告","ItemSystem_LackOfHoney","ItemSystem_LackOfHoney_Check")

function ItemSystem_ExploreForest()
    TUR()MSG("\n*探索西边森林*")W99()
end
function ItemSystem_ExploreForest_Check()
    MSG("制枪者说在西边森林里看到过蜂巢，")NOD()
    CAT("\n去那里探索一下吧。")NOD()
    W99()
end
RGM("ExploreForest","CS_mission_jack","探索西边森林","ItemSystem_ExploreForest","ItemSystem_ExploreForest_Check")

function ItemSystem_BringHoneycombToGunsmith()
    TUR()MSG("\n*把蜂巢带给制枪者*")W99()
end
function ItemSystem_BringHoneycombToGunsmith_Check()
    MSG("把蜂巢带给制枪者，")NOD()
    CAT("\n他会帮我们从里面提取出蜂蜜。")NOD()
    W99()
end
RGM("BringHoneycombToGunsmith","CS_mission_jack","把蜂巢带给制枪者","ItemSystem_BringHoneycombToGunsmith","ItemSystem_BringHoneycombToGunsmith_Check")

function ItemSystem_BringHoneyToBaker()
    TUR()MSG("\n*把蜂蜜带给糕点师*")W99()
end
function ItemSystem_BringHoneyToBaker_Check()
    MSG("把蜂蜜带给糕点师，")NOD()
    CAT("\n他就能继续制作甜点了。")NOD()
    W99()
end
RGM("BringHoneyToBaker","CS_mission_jack","把蜂蜜带给糕点师","ItemSystem_BringHoneyToBaker","ItemSystem_BringHoneyToBaker_Check")

function ItemSystem_BringDoughnutToGunsmith()
    TUR()MSG("\n*把甜点带给制枪者*")W99()
end
function ItemSystem_BringDoughnutToGunsmith_Check()
    MSG("把甜点带给制枪者，")NOD()
    CAT("\n他就能给枪制作新的功能了。")NOD()
    W99()
end
RGM("BringDoughnutToGunsmith","CS_mission_jack","把甜点带给制枪者","ItemSystem_BringDoughnutToGunsmith","ItemSystem_BringDoughnutToGunsmith_Check")

function ItemSystem_CatchFirefly()
    TUR()MSG("\n*去抓萤火虫吧*")W99()
end
function ItemSystem_CatchFirefly_Check()
    MSG("萤火虫在西边的洞窟里，")NOD()
    CAT("\n去抓一些带给米莎莉吧。")NOD()
    W99()
end
RGM("CatchFirefly","CS_mission_jack","去抓萤火虫吧","ItemSystem_CatchFirefly","ItemSystem_CatchFirefly_Check")

function ItemSystem_GiveToMisery()
    TUR()MSG("\n*把萤火虫送给米莎莉吧*")W99()
end
function ItemSystem_GiveToMisery_Check()
    MSG("把萤火虫送给米莎莉的话，")NOD()
    CAT("\n也许她心情会变好，愿意帮助我们。")NOD()
    W99()
end
RGM("GiveToMisery","CS_mission_jack","把萤火虫送给米莎莉吧","ItemSystem_GiveToMisery","ItemSystem_GiveToMisery_Check")

function ItemSystem_GoFindJenka()
    TUR()MSG("\n*寻找珍卡*")W99()
end
function ItemSystem_GoFindJenka_Check()
    MSG("离开小镇穿过火之洞窟去寻找珍卡，")NOD()
    CAT("\n珍卡婆婆能帮助我们找到多隆子。")NOD()
    W99()
end
RGM("GoFindJenka","CS_mission_jack","寻找珍卡","ItemSystem_GoFindJenka","ItemSystem_GoFindJenka_Check")

function ItemSystem_SaveEveryone()
    TUR()MSG("\n*救回大家*")W99()
end
function ItemSystem_SaveEveryone_Check()
    MSG("大家被怪物关在了铁牢里，")NOD()
    CAT("\n我们得想办法救大家出来。")NOD()W99()
end
RGM("SaveEveryone","CS_mission_jack","救回大家","ItemSystem_SaveEveryone","ItemSystem_SaveEveryone_Check")

function ItemSystem_BringSomeFood()
    TUR()MSG("\n*找些食物带些大家*")W99()
end
function ItemSystem_BringSomeFood_Check()
    MSG("数她们被关在铁牢里饿极了，")NOD()
    CAT("\n去附近找点能吃的带给她们吧...")NOD()W99()
end
RGM("BringSomeFood","CS_mission_jack","找些食物带些大家","ItemSystem_BringSomeFood","ItemSystem_BringSomeFood_Check")

function ItemSystem_ExploreEscapeRoutes()
    TUR()MSG("\n*探索逃跑路线*")W99()
end
function ItemSystem_ExploreEscapeRoutes_Check()
    MSG("在把大家救出来前，")NOD()
    CAT("\n去附近探索一下逃跑路线吧。")NOD()W99()
end
RGM("ExploreEscapeRoutes","CS_mission_jack","探索逃跑路线","ItemSystem_ExploreEscapeRoutes","ItemSystem_ExploreEscapeRoutes_Check")

function ItemSystem_SaveEveryone_King()
    TUR()MSG("\n*救回大家*")W99()
end
function ItemSystem_SaveEveryone_King_Check()
    MSG("大家被怪物抓走了，")NOD()
    CAT("\n向洞窟深处前进，救回大家吧！")NOD()W99()
end
RGM("SaveEveryoneKing","CS_mission_king","救回大家","ItemSystem_SaveEveryone_King","ItemSystem_SaveEveryone_King_Check")

==> ocstore25_6_20.zip: OcStore/Prgm/data/CS_mission.lua <==
----------------任务---------------
function ItemSystem_AskEveryoneAboutMahin()
    TUR()MSG("\n*向大家询问马宾去向*")W99()
end
function ItemSystem_AskEveryoneAboutMahin_Check()
    MSG("去向村子里大家询问一下")
    CAT("\n马宾的下落吧。")NOD()W99()
end
RGM("AskEveryoneAboutMahin","CS_mission_kanpa","向大家询问马宾去向","ItemSystem_AskEveryoneAboutMahin","ItemSystem_AskEveryoneAboutMahin_Check")

function ItemSystem_GoHomeSleep()
    TUR()MSG("\n*回家睡觉*")W99()
end
function ItemSystem_GoHomeSleep_Check()
    MSG("太阳已经下山了")
    CAT("\n回屋子休息吧。")NOD()W99()
end
RGM("GoHomeSleep","CS_mission_kanpa","回家睡觉","ItemSystem_GoHomeSleep","ItemSystem_GoHomeSleep_Check")

function ItemSystem_SearchForMahin()
    TUR()MSG("\n*出发寻找马宾*")W99()
end
function ItemSystem_SearchForMahin_Check()
    MSG("马宾已经失踪三天了")
    CAT("\n我得去村子外边找他。")NOD()W99()
end
RGM("SearchForMahin","CS_mission_kanpa","出发寻找马宾","ItemSystem_SearchForMahin","ItemSystem_SearchForMahin_Check")

function ItemSystem_Fishing()
    TUR()MSG("\n*去钓大鱼吧*")W99()
end
function ItemSystem_Fishing_Check()
    MSG("钓大鱼去喂给猫先生吧~")
    CAT("\n这样它就会帮我一起找马宾了。")NOD()W99()
end
RGM("Fishing","CS_mission_monsterx","去钓大鱼吧","ItemSystem_Fishing","ItemSystem_Fishing_Check")

function ItemSystem_BackVillageReport()
    TUR()MSG("\n*回村报告*")W99()
end
function ItemSystem_BackVillageReport_Check()
    MSG("今天时间已经晚了，")
    CAT("\n得回村子和杰克报告一下...")NOD()W99()
end
RGM("BackVillageReport","CS_mission_kanpa","回村报告","ItemSystem_BackVillageReport","ItemSystem_BackVillageReport_Check")

function ItemSystem_SaveToroko()
    TUR()MSG("\n*救回多隆子*")W99()
end
function ItemSystem_SaveToroko_Check()
    MSG("多隆子被怪物抓走了，")
    CAT("\n我们必须去救回她...")NOD()W99()
end
RGM("SaveToroko","CS_mission_jack","救回多隆子","ItemSystem_SaveToroko","ItemSystem_SaveToroko_Check")

function ItemSystem_AskMiseryForHelp()
    TUR()MSG("\n*向米莎莉求助*")W99()
end
function ItemSystem_AskMiseryForHelp_Check()
    MSG("向米莎莉求助试试")
    CAT("\n寻找救回多隆子的方法...")NOD()W99()
end
RGM("AskMiseryForHelp","CS_mission_jack","向米莎莉求助","ItemSystem_AskMiseryForHelp","ItemSystem_AskMiseryForHelp_Check")

function ItemSystem_AskBalrogForHelp()
    TUR()MSG("\n*向巴鲁罗格求助*")W99()
end
function ItemSystem_AskBalrogForHelp_Check()
    MSG("不小心惹米莎莉生气了")
    CAT("\n回酒店再向巴鲁罗格问一下吧...")NOD()W99()
end
RGM("AskBalrogForHelp","CS_mission_jack","向巴鲁罗格求助","ItemSystem_AskBalrogForHelp","ItemSystem_AskBalrogForHelp_Check")

function ItemSystem_SearchingForMethodsToCaptureFireflies()
    TUR()MSG("\n*寻找捕获萤火虫的方法*")W99()
end
function ItemSystem_SearchingForMethodsToCaptureFireflies_Check()
    MSG("听巴鲁罗格说")
    CAT("\n米莎莉小时候喜欢萤火虫。")NOD()CLR()
    CAT("不过目前我们没有捕获萤火虫的工具，")NOD()
    CAT("\n得在这个小镇上寻找方法。")NOD()W99()
end
RGM("SearchingForMethodsToCaptureFireflies","CS_mission_jack","寻找捕获萤火虫的方法",
"ItemSystem_SearchingForMethodsToCaptureFireflies","ItemSystem_SearchingForMethodsToCaptureFireflies_Check")

function ItemSystem_GetTranslator()
    TUR()MSG("\n*取得一台翻译机*")W99()
end
function ItemSystem_GetTranslator_Check()
    MSG("如果要和人类对话的话，")NOD()
    CAT("\n需要一台翻译机。")NOD()CLR()
    CAT("伊格尔说回收店里也许有翻译机卖，")NOD()
    CAT("\n我们得去回收店看看。")NOD()W99()
end
RGM("GetTranslator","CS_mission_jack","取得一台翻译机","ItemSystem_GetTranslator","ItemSystem_GetTranslator_Check")

function ItemSystem_AskGunsmithForHelp()
    TUR()MSG("\n*向制枪者求助*")W99()
end
function ItemSystem_AskGunsmithForHelp_Check()
    MSG("听茶羽说制枪者")
    CAT("\n能帮我们找到捕获办法，")NOD()
    CAT("\n去他的维修店里看一下吧。")NOD()
    W99()
end
RGM("AskGunsmithForHelp","CS_mission_jack","向制枪者求助","ItemSystem_AskGunsmithForHelp","ItemSystem_AskGunsmithForHelp_Check")

function ItemSystem_BringSomeDessert()
    TUR()MSG("\n*带甜点给制枪者*")W99()
end
function ItemSystem_BringSomeDessert_Check()
    if(GOP() == 1) then
        MSG("制枪者需要吃一些甜点恢复脑力来制作，")NOD()
        CAT("\n去蛋糕店看一下吧。")NOD()W99()
    else
        MSG("制枪者需要吃一些")
        CAT("\n甜点恢复脑力来制作，")NOD()
        CAT("\n去蛋糕店看一下吧。")NOD()W99()
    end
end
RGM("BringSomeDessert","CS_mission_jack","带甜点给制枪者","ItemSystem_BringSomeDessert","ItemSystem_BringSomeDessert_Check")

function ItemSystem_LackOfHoney()
    TUR()MSG("\n*缺少蜂蜜的报告*")W99()
end
function ItemSystem_LackOfHoney_Check()
    MSG("把蛋糕店无法继续制作甜点的原因")
    CAT("\n和制枪者说一下吧。")NOD()
    W99()
end
RGM("LackOfHoney","CS_mission_jack","缺少蜂蜜的报告","ItemSystem_LackOfHoney","ItemSystem_LackOfHoney_Check")

function ItemSystem_ExploreForest()
    TUR()MSG("\n*探索西边森林*")W99()
end
function ItemSystem_ExploreForest_Check()
    MSG("制枪者说在西边森林里看到过蜂巢，")NOD()
    CAT("\n去那里探索一下吧。")NOD()
    W99()
end
RGM("ExploreForest","CS_mission_jack","探索西边森林","ItemSystem_ExploreForest","ItemSystem_ExploreForest_Check")

function ItemSystem_BringHoneycombToGunsmith()
    TUR()MSG("\n*把蜂巢带给制枪者*")W99()
end
function ItemSystem_BringHoneycombToGunsmith_Check()
    MSG("把蜂巢带给制枪者，")NOD()
    CAT("\n他会帮我们从里面提取出蜂蜜。")NOD()
    W99()
end
RGM("BringHoneycombToGunsmith","CS_mission_jack","把蜂巢带给制枪者","ItemSystem_BringHoneycombToGunsmith","ItemSystem_BringHoneycombToGunsmith_Check")

function ItemSystem_BringHoneyToBaker()
    TUR()MSG("\n*把蜂蜜带给糕点师*")W99()
end
function ItemSystem_BringHoneyToBaker_Check()
    MSG("把蜂蜜带给糕点师，")NOD()
    CAT("\n他就能继续制作甜点了。")NOD()
    W99()
end
RGM("BringHoneyToBaker","CS_mission_jack","把蜂蜜带给糕点师","ItemSystem_BringHoneyToBaker","ItemSystem_BringHoneyToBaker_Check")

function ItemSystem_BringDoughnutToGunsmith()
    TUR()MSG("\n*把甜点带给制枪者*")W99()
end
function ItemSystem_BringDoughnutToGunsmith_Check()
    MSG("把甜点带给制枪者，")NOD()
    CAT("\n他就能给枪制作新的功能了。")NOD()
    W99()
end
RGM("BringDoughnutToGunsmith","CS_mission_jack","把甜点带给制枪者","ItemSystem_BringDoughnutToGunsmith","ItemSystem_BringDoughnutToGunsmith_Check")

function ItemSystem_CatchFirefly()
    TUR()MSG("\n*去抓萤火虫吧*")W99()
end
function ItemSystem_CatchFirefly_Check()
    MSG("萤火虫在西边的洞窟里，")NOD()
    CAT("\n去抓一些带给米莎莉吧。")NOD()
    W99()
end
RGM("CatchFirefly","CS_mission_jack","去抓萤火虫吧","ItemSystem_CatchFirefly","ItemSystem_CatchFirefly_Check")

function ItemSystem_GiveToMisery()
    TUR()MSG("\n*把萤火虫送给米莎莉吧*")W99()
end
function ItemSystem_GiveToMisery_Check()
    MSG("把萤火虫送给米莎莉的话，")NOD()
    CAT("\n也许她心情会变好，愿意帮助我们。")NOD()
    W99()
end
RGM("GiveToMisery","CS_mission_jack","把萤火虫送给米莎莉吧","ItemSystem_GiveToMisery","ItemSystem_GiveToMisery_Check")

function ItemSystem_GoFindJenka()
    TUR()MSG("\n*寻找珍卡*")W99()
end
function ItemSystem_GoFindJenka_Check()
    MSG("离开小镇穿过火之洞窟去寻找珍卡，")NOD()
    CAT("\n珍卡婆婆能帮助我们找到多隆子。")NOD()
    W99()
end
RGM("GoFindJenka","CS_mission_jack","寻找珍卡","ItemSystem_GoFindJenka","ItemSystem_GoFindJenka_Check")

function ItemSystem_SaveEveryone()
    TUR()MSG("\n*救回大家*")W99()
end
function ItemSystem_SaveEveryone_Check()
    MSG("大家被怪物关在了铁牢里，")NOD()
    CAT("\n我们得想办法救大家出来。")NOD()W99()
end
RGM("SaveEveryone","CS_mission_jack","救回大家","ItemSystem_SaveEveryone","ItemSystem_SaveEveryone_Check")

function ItemSystem_BringSomeFood()
    TUR()MSG("\n*找些食物带些大家*")W99()
end
function ItemSystem_BringSomeFood_Check()
    MSG("数她们被关在铁牢里饿极了，")NOD()
    CAT("\n去附近找点能吃的带给她们吧...")NOD()W99()
end
RGM("BringSomeFood","CS_mission_jack","找些食物带些大家","ItemSystem_BringSomeFood","ItemSystem_BringSomeFood_Check")

function ItemSystem_ExploreEscapeRoutes()
    TUR()MSG("\n*探索逃跑路线*")W99()
end
function ItemSystem_ExploreEscapeRoutes_Check()
    MSG("在把大家救出来前，")NOD()
    CAT("\n去附近探索一下逃跑路线吧。")NOD()W99()
end
RGM("ExploreEscapeRoutes","CS_mission_jack","探索逃跑路线","ItemSystem_ExploreEscapeRoutes","ItemSystem_ExploreEscapeRoutes_Check")

function ItemSystem_SaveEveryone_King()
    TUR()MSG("\n*救回大家*")W99()
end
function ItemSystem_SaveEveryone_King_Check()
    MSG("大家被怪物抓走了，")NOD()
    CAT("\n向洞窟深处前进，救回大家吧！")NOD()W99()
end
RGM("SaveEveryoneKing","CS_mission_king","救回大家","ItemSystem_SaveEveryone_King","ItemSystem_SaveEveryone_King_Check")

function ItemSystem_SaveEveryone_Curly()
    TUR()MSG("\n*救回大家*")W99()
end
function ItemSystem_SaveEveryone_Curly_Check()
    MSG("大家被怪物抓走了，")NOD()
    CAT("\n打倒所有敌人救回大家吧！")NOD()W99()
end
RGM("SaveEveryoneCurly","CS_mission_curly","救回大家","ItemSystem_SaveEveryone_Curly","ItemSystem_SaveEveryone_Curly_Check")

function ItemSystem_FindMahinFinally()
    TUR()MSG("\n*寻找马宾*")W99()
end
function ItemSystem_FindMahinFinally_Check()
    MSG("马宾一定还在这个地方的某处，")NOD()
    CAT("\n我必须去找到他。")NOD()W99()
end
RGM("FindMahinFinally","CS_mission_kanpa","寻找马宾","ItemSystem_FindMahinFinally","ItemSystem_FindMahinFinally_Check")
